==> skytemple-1.6.0a2-py3-none-any.whl: skytemple/module/map_bg/chunk_editor_data_provider/tile_graphics_provider.py <==
#  Copyright 2020-2023 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.
from abc import ABC
from typing import List, Sequence

from skytemple.module.tiled_img.chunk_editor_data_provider.tile_graphics_provider import AbstractTileGraphicsProvider
from skytemple_files.graphics.bpa.protocol import BpaProtocol
from skytemple_files.graphics.bpc.protocol import BpcProtocol


class MapBgStaticTileProvider(AbstractTileGraphicsProvider):
    def __init__(self, bpc: BpcProtocol, layer_number: int):
        self.bpc = bpc
        self.layer_number = layer_number

    def get_pil(self, palettes: Sequence[Sequence[int]], pal_idx: int):
        return self.bpc.tiles_to_pil(self.layer_number, palettes, 1, pal_idx)

    def count(self):
        return len(self.bpc.layers[self.layer_number].tiles)


class MapBgAnimatedTileProvider(AbstractTileGraphicsProvider):
    def __init__(self, bpa: BpaProtocol):
        self.bpa = bpa

    def get_pil(self, palettes: Sequence[Sequence[int]], pal_idx: int):
        return self.bpa.tiles_to_pil_separate(palettes[pal_idx], 1)

    def count(self):
        return self.bpa.number_of_tiles

==> skytemple-1.6.2-py3-none-any.whl: skytemple/module/map_bg/chunk_editor_data_provider/tile_graphics_provider.py <==
#  Copyright 2020-2023 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.
from abc import ABC
from typing import List
from collections.abc import Sequence

from skytemple.module.tiled_img.chunk_editor_data_provider.tile_graphics_provider import (
    AbstractTileGraphicsProvider,
)
from skytemple_files.graphics.bpa.protocol import BpaProtocol
from skytemple_files.graphics.bpc.protocol import BpcProtocol


class MapBgStaticTileProvider(AbstractTileGraphicsProvider):
    def __init__(self, bpc: BpcProtocol, layer_number: int):
        self.bpc = bpc
        self.layer_number = layer_number

    def get_pil(self, palettes: Sequence[Sequence[int]], pal_idx: int):
        return self.bpc.tiles_to_pil(self.layer_number, palettes, 1, pal_idx)

    def count(self):
        return len(self.bpc.layers[self.layer_number].tiles)


class MapBgAnimatedTileProvider(AbstractTileGraphicsProvider):
    def __init__(self, bpa: BpaProtocol):
        self.bpa = bpa

    def get_pil(self, palettes: Sequence[Sequence[int]], pal_idx: int):
        return self.bpa.tiles_to_pil_separate(palettes[pal_idx], 1)

    def count(self):
        return self.bpa.number_of_tiles
